==> server-core-3.7.2-sources.jar: com/xebialabs/deployit/security/authentication/BasicAuthWithRememberMeFilter.java <==
package com.xebialabs.deployit.security.authentication;

import org.springframework.security.authentication.*;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.crypto.codec.Base64;
import org.springframework.security.web.AuthenticationEntryPoint;
import org.springframework.security.web.authentication.WebAuthenticationDetailsSource;
import org.springframework.security.web.authentication.www.BasicAuthenticationFilter;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

public class BasicAuthWithRememberMeFilter extends BasicAuthenticationFilter {

	@Override
    protected void onSuccessfulAuthentication(HttpServletRequest request, HttpServletResponse response, Authentication authResult) throws IOException {
		// Extract password because that is no longer in authResult.
		String header = request.getHeader("Authorization");
		String[] tokens = extractAndDecodeHeader(header, request);
		UsernamePasswordAuthenticationToken token = new UsernamePasswordAuthenticationToken(authResult.getName(), tokens[1], authResult.getAuthorities());
		token.setDetails(authResult.getDetails());
		RememberMe.remember(token);
    }

	/**
	 * Decodes the header into a username and password.
	 *
	 * @throws BadCredentialsException if the Basic header is not present or is not valid Base64
	 */
	private String[] extractAndDecodeHeader(String header, HttpServletRequest request) throws IOException {

		byte[] base64Token = header.substring(6).getBytes("UTF-8");
		byte[] decoded;
		try {
			decoded = Base64.decode(base64Token);
		} catch (IllegalArgumentException e) {
			throw new BadCredentialsException("Failed to decode basic authentication token");
		}

		String token = new String(decoded, getCredentialsCharset(request));

		int delim = token.indexOf(":");

		if (delim == -1) {
			throw new BadCredentialsException("Invalid basic authentication token");
		}
		return new String[] {token.substring(0, delim), token.substring(delim + 1)};
	}
}

==> server-core-3.7.3-sources.jar: com/xebialabs/deployit/security/authentication/BasicAuthWithRememberMeFilter.java <==
package com.xebialabs.deployit.security.authentication;

import org.springframework.security.authentication.*;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.crypto.codec.Base64;
import org.springframework.security.web.AuthenticationEntryPoint;
import org.springframework.security.web.authentication.WebAuthenticationDetailsSource;
import org.springframework.security.web.authentication.www.BasicAuthenticationFilter;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

public class BasicAuthWithRememberMeFilter extends BasicAuthenticationFilter {

	public BasicAuthWithRememberMeFilter(AuthenticationManager authenticationManager, AuthenticationEntryPoint authenticationEntryPoint) {
		super(authenticationManager, authenticationEntryPoint);
	}

	@Override
    protected void onSuccessfulAuthentication(HttpServletRequest request, HttpServletResponse response, Authentication authResult) throws IOException {
		// Extract password because that is no longer in authResult.
		String header = request.getHeader("Authorization");
		String[] tokens = extractAndDecodeHeader(header, request);
		UsernamePasswordAuthenticationToken token = new UsernamePasswordAuthenticationToken(authResult.getName(), tokens[1], authResult.getAuthorities());
		token.setDetails(authResult.getDetails());
		if (request.getRequestURI().contains("logout")) {
			RememberMe.forget(token);
		} else {
			RememberMe.remember(token);
		}
    }

	/**
	 * Decodes the header into a username and password.
	 *
	 * @throws BadCredentialsException if the Basic header is not present or is not valid Base64
	 */
	private String[] extractAndDecodeHeader(String header, HttpServletRequest request) throws IOException {

		byte[] base64Token = header.substring(6).getBytes("UTF-8");
		byte[] decoded;
		try {
			decoded = Base64.decode(base64Token);
		} catch (IllegalArgumentException e) {
			throw new BadCredentialsException("Failed to decode basic authentication token");
		}

		String token = new String(decoded, getCredentialsCharset(request));

		int delim = token.indexOf(":");

		if (delim == -1) {
			throw new BadCredentialsException("Invalid basic authentication token");
		}
		return new String[] {token.substring(0, delim), token.substring(delim + 1)};
	}
}
